import { useState, useEffect } from 'react';
import { Observable } from 'object-observer';
const isObject = (value) => value !== null && typeof value === 'object';
export class Store {
    value;
    constructor(value) {
        if (!isObject(value))
            throw new Error('Store value should be an object');
        this.value = Observable.from(value, { async: true });
    }
    observe(callback, options) {
        Observable.observe(this.value, callback, typeof options === 'string' ? { pathsFrom: options } : options);
    }
    unobserve() {
        Observable.unobserve(this.value);
    }
}
export function useStore(store, options) {
    let [, setRevision] = useState(0);
    if (!(store instanceof Store))
        throw new Error('The first argument should be an instance of Store');
    useEffect(() => {
        store.observe(() => {
            setRevision(Math.random());
        }, options);
        return () => {
            store.unobserve();
        };
    }, [store, options]);
    return store.value;
}
